utils

package
v1.5.7-0...-de8b4f8 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Nov 30, 2025 License: MIT Imports: 9 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func ConvertArguments

func ConvertArguments(argument, value string) []string

ConvertArguments converts arguments like "minecraft_versions" or "launchers"

func CopyConfigurations

func CopyConfigurations(version, launcher string, quiet bool) error

CopyConfigurations copies everything from the root configurations directory and then from {version}/configurations/ into {version}/{launcher}/

func FindPackToml

func FindPackToml(root string) (string, error)

findPackToml recursively searches root for a file named pack.toml and returns its full path if found.

Types

This section is empty.

Jump to